==> apache-plc4x-0.10.0-source-release.zip: apache-plc4x-0.10.0/plc4go/pkg/api/model/plc_read.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import (
	"context"
	"github.com/apache/plc4x/plc4go/pkg/api/values"
)

type PlcReadRequestBuilder interface {
	AddQuery(name string, query string) PlcReadRequestBuilder
	AddField(name string, field PlcField) PlcReadRequestBuilder
	Build() (PlcReadRequest, error)
}

type PlcReadRequestResult interface {
	GetRequest() PlcReadRequest
	GetResponse() PlcReadResponse
	GetErr() error
}

type PlcReadRequest interface {
	PlcRequest
	Execute() <-chan PlcReadRequestResult
	ExecuteWithContext(ctx context.Context) <-chan PlcReadRequestResult
	GetFieldNames() []string
	GetField(name string) PlcField
}

type PlcReadResponse interface {
	PlcResponse
	GetRequest() PlcReadRequest
	GetFieldNames() []string
	GetResponseCode(name string) PlcResponseCode
	GetValue(name string) values.PlcValue
}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4go/pkg/api/model/plc_read.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package model

import (
	"context"
	"fmt"

	"github.com/apache/plc4x/plc4go/pkg/api/values"
)

type PlcReadRequestBuilder interface {
	fmt.Stringer
	AddTagAddress(tagName string, tagAddress string) PlcReadRequestBuilder
	AddTag(tagName string, tag PlcTag) PlcReadRequestBuilder
	Build() (PlcReadRequest, error)
}

type PlcReadRequestResult interface {
	fmt.Stringer
	GetRequest() PlcReadRequest
	GetResponse() PlcReadResponse
	GetErr() error
}

type PlcReadRequest interface {
	PlcRequest
	Execute() <-chan PlcReadRequestResult
	ExecuteWithContext(ctx context.Context) <-chan PlcReadRequestResult

	GetTagNames() []string
	GetTag(tagName string) PlcTag
}

type PlcReadResponse interface {
	PlcResponse
	GetRequest() PlcReadRequest
	GetTagNames() []string
	GetResponseCode(tagName string) PlcResponseCode
	GetValue(tagName string) values.PlcValue
}
